All of lore.kernel.org
 help / color / mirror / Atom feed
* [igt-dev] [PATCH i-g-t 1/1] Rename dynamic subtest blocks
@ 2019-11-18 11:09 Petri Latvala
  2019-11-18 11:16 ` Chris Wilson
                   ` (4 more replies)
  0 siblings, 5 replies; 7+ messages in thread
From: Petri Latvala @ 2019-11-18 11:09 UTC (permalink / raw)
  To: igt-dev; +Cc: Tvrtko Ursulin, Petri Latvala

The final naming for the magic block identifiers is:

igt_subtest_with_dynamic("do-stuff-on-things") {
    for_each_thing(x) {
        igt_dynamic_f("%s", x->name) {
	    do_stuff(x);
	}
    }
}

Signed-off-by: Petri Latvala <petri.latvala@intel.com>
Cc: Chris Wilson <chris@chris-wilson.co.uk>
Cc: Tvrtko Ursulin <tvrtko.ursulin@intel.com>
Cc: Arkadiusz Hiler <arkadiusz.hiler@intel.com>
Cc: Katarzyna Dec <katarzyna.dec@intel.com>
---

NOTE!

The commit message is worded as being the final decision, but it's of
course just a suggestion for the final naming and won't be used
without acks, especially the people who have pointed out the awfulness
of the naming. With luck I might have succeeded in CCing all of them
and people otherwise involved in reviewing dynamic subtests.

These names meet the requirements laid out in words on the mailing
list:

* makes it clear that the subtest that can have dynamic runtime parts
  is a subtest more than an igt_subtest_group
* don't completely destroy ickle's keyboard


lib/igt_core.c                   |  4 +--
 lib/igt_core.h                   | 46 ++++++++++++++++----------------
 lib/tests/igt_describe.c         |  4 +--
 lib/tests/igt_dynamic_subtests.c | 18 ++++++-------
 4 files changed, 36 insertions(+), 36 deletions(-)

diff --git a/lib/igt_core.c b/lib/igt_core.c
index a0c673d1..99aa0bee 100644
--- a/lib/igt_core.c
+++ b/lib/igt_core.c
@@ -127,7 +127,7 @@
  *
  * - Code blocks with magic control flow are implemented with setjmp()
  *   and longjmp(). This applies to #igt_fixture, #igt_subtest,
- *   #igt_subtest_with_dynamic_subsubtests and #igt_dynamic_subsubtest
+ *   #igt_subtest_with_dynamic and #igt_dynamic
  *   blocks and all the three variants to finish test: igt_success(),
  *   igt_skip() and igt_fail(). Mostly this is of no concern, except
  *   when such a control block changes stack variables defined in the
@@ -1281,7 +1281,7 @@ static void exit_subtest(const char *result)
 	const char *subtest_text = in_dynamic_subtest ? "Dynamic subtest" : "Subtest";
 	const char **subtest_name = in_dynamic_subtest ? &in_dynamic_subtest : &in_subtest;
 	struct timespec *thentime = in_dynamic_subtest ? &dynamic_subtest_time : &subtest_time;
-	jmp_buf *jmptarget = in_dynamic_subtest ? &igt_dynamic_subsubtest_jmpbuf : &igt_subtest_jmpbuf;
+	jmp_buf *jmptarget = in_dynamic_subtest ? &igt_dynamic_jmpbuf : &igt_subtest_jmpbuf;
 
 	igt_gettime(&now);
 
diff --git a/lib/tests/igt_describe.c b/lib/tests/igt_describe.c
index 7ea3b961..6f3a4319 100644
--- a/lib/tests/igt_describe.c
+++ b/lib/tests/igt_describe.c
@@ -88,10 +88,10 @@ static void fake_main(int argc, char **argv) {
 		;
 
 	igt_describe("Subtest with dynamic subsubtests");
-	igt_subtest_with_dynamic_subsubtests("G") {
+	igt_subtest_with_dynamic("G") {
 		printf("should not be executed!\n");
 		igt_describe("should assert on execution");
-		igt_dynamic_subsubtest("should-not-list")
+		igt_dynamic("should-not-list")
 			printf("should not be executed!\n");
 	}
 
diff --git a/lib/tests/igt_dynamic_subtests.c b/lib/tests/igt_dynamic_subtests.c
index 82d80a77..606104c5 100644
--- a/lib/tests/igt_dynamic_subtests.c
+++ b/lib/tests/igt_dynamic_subtests.c
@@ -56,7 +56,7 @@ static void dynamic_subtest_in_normal_subtest(void)
 	igt_subtest_init(fake_argc, fake_argv);
 
 	igt_subtest("normal-subtest") {
-		igt_dynamic_subsubtest("dynamic") {
+		igt_dynamic("dynamic") {
 			igt_info("Dynamic subtest in normal subtest\n");
 		}
 	}
@@ -72,8 +72,8 @@ static void invalid_dynamic_subtest_name(void)
 
 	igt_subtest_init(fake_argc, fake_argv);
 
-	igt_subtest_with_dynamic_subsubtests("subtest") {
-		igt_dynamic_subsubtest("# invalid name !") {
+	igt_subtest_with_dynamic("subtest") {
+		igt_dynamic("# invalid name !") {
 			igt_info("Invalid dynamic subtest name test\n");
 		}
 	}
@@ -89,7 +89,7 @@ static void dynamic_subtest_in_toplevel(void)
 
 	igt_subtest_init(fake_argc, fake_argv);
 
-	igt_dynamic_subsubtest("dynamic-subtest-in-toplevel") {
+	igt_dynamic("dynamic-subtest-in-toplevel") {
 		igt_info("Dynamic subtests need to be in a subtest\n");
 	}
 
@@ -104,7 +104,7 @@ static void subtest_itself_failing(void)
 
 	igt_subtest_init(fake_argc, fake_argv);
 
-	igt_subtest_with_dynamic_subsubtests("subtest") {
+	igt_subtest_with_dynamic("subtest") {
 		igt_assert(false);
 	}
 
@@ -119,7 +119,7 @@ static void subtest_itself_skipping(void)
 
 	igt_subtest_init(fake_argc, fake_argv);
 
-	igt_subtest_with_dynamic_subsubtests("subtest") {
+	igt_subtest_with_dynamic("subtest") {
 		igt_skip("Skipping\n");
 	}
 
@@ -134,8 +134,8 @@ static void dynamic_subtest_failure_leads_to_fail(void)
 
 	igt_subtest_init(fake_argc, fake_argv);
 
-	igt_subtest_with_dynamic_subsubtests("subtest") {
-		igt_dynamic_subsubtest("dynamic") {
+	igt_subtest_with_dynamic("subtest") {
+		igt_dynamic("dynamic") {
 			igt_assert(false);
 		}
 	}
@@ -151,7 +151,7 @@ static void no_dynamic_subtests_entered_leads_to_skip(void)
 
 	igt_subtest_init(fake_argc, fake_argv);
 
-	igt_subtest_with_dynamic_subsubtests("subtest") {
+	igt_subtest_with_dynamic("subtest") {
 	}
 
 	igt_exit();
diff --git a/lib/igt_core.h b/lib/igt_core.h
index 86bc1b41..c17a7ba8 100644
--- a/lib/igt_core.h
+++ b/lib/igt_core.h
@@ -146,7 +146,7 @@ void __igt_fixture_end(void) __attribute__((noreturn));
 
 /* subtest infrastructure */
 jmp_buf igt_subtest_jmpbuf;
-jmp_buf igt_dynamic_subsubtest_jmpbuf;
+jmp_buf igt_dynamic_jmpbuf;
 typedef int (*igt_opt_handler_t)(int opt, int opt_index, void *data);
 #define IGT_OPT_HANDLER_SUCCESS 0
 #define IGT_OPT_HANDLER_ERROR -2
@@ -230,7 +230,7 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
 	__igt_subtest_f(igt_tokencat(__tmpchar, __LINE__), f)
 
 /**
- * igt_subtest_with_dynamic_subsubtests:
+ * igt_subtest_with_dynamic:
  * @name: name of the subtest
  *
  * This is a magic control flow block which denotes a subtest code
@@ -238,13 +238,13 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
  * printf format string, which is useful for constructing
  * combinatorial tests.
  *
  * See igt_subtest_with_dynamic_subsubtests_f() for documentation.
  */
-#define igt_subtest_with_dynamic_subsubtests(name) for (; __igt_run_subtest((name), __FILE__, __LINE__) && \
+#define igt_subtest_with_dynamic(name) for (; __igt_run_subtest((name), __FILE__, __LINE__) && \
 							 __igt_enter_dynamic_container() && \
 							 (sigsetjmp(igt_subtest_jmpbuf, 1) == 0); \
 						 igt_success())
-#define __igt_subtest_with_dynamic_subsubtests_f(tmp, format...) \
+#define __igt_subtest_with_dynamic_f(tmp, format...) \
 	for (char tmp [256]; \
 	     snprintf( tmp , sizeof( tmp ), \
 		      format), \
@@ -254,7 +254,7 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
 	     igt_success())
 
 /**
- * igt_subtest_with_dynamic_subsubtests_f:
+ * igt_subtest_with_dynamic_f:
  * @...: format string and optional arguments
  *
  * This is a magic control flow block which denotes a subtest code
@@ -275,12 +275,12 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
  * subsubtest for each pipe and performs the operation for that pipe
  * in there.
  *
- * The result of a subtest igt_subtest_with_dynamic_subsubtests will be
+ * The result of a subtest igt_subtest_with_dynamic will be
  * * SKIP, if no dynamic subsubtests are entered
  * * PASS, if _all_ dynamic subsubtests PASS
  * * FAIL, if _any_ dynamic subsubtests FAIL
  *
- * Within a igt_subtest_with_dynamic_subsubtests block, explicit
+ * Within a igt_subtest_with_dynamic block, explicit
  * failure (e.g. igt_assert) is not allowed, only dynamic subsubtests
  * themselves will produce test results. igt_skip()/igt_require() is
  * allowed. Example:
@@ -288,7 +288,7 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
  * |[<!-- language="C" -->
  * igt_main
  * {
- *     igt_subtest_with_dynamic_subsubtests("engine-tests") {
+ *     igt_subtest_with_dynamic("engine-tests") {
  *               igt_require(is_awesome(fd)); // requires ok here
  *
  *               for_each_engine(fd, e) {
@@ -300,14 +300,14 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
  * }
  * ]|
  *
- * Like igt_subtest_with_dynamic_subsubtests(), but also accepts a printf
+ * Like igt_subtest_with_dynamic(), but also accepts a printf
  * format string instead of a static string.
  */
-#define igt_subtest_with_dynamic_subsubtests_f(f...) \
-	__igt_subtest_with_dynamic_subsubtests_f(igt_tokencat(__tmpchar, __LINE__), f)
+#define igt_subtest_with_dynamic_f(f...) \
+	__igt_subtest_with_dynamic_f(igt_tokencat(__tmpchar, __LINE__), f)
 
 /**
- * igt_dynamic_subsubtest:
+ * igt_dynamic:
  * @name: name of the dynamic subtest
  *
  * This is a magic control flow block which denotes a dynamic
@@ -316,22 +316,22 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
  * variant accepts a printf format string, which is useful for
  * constructing combinatorial tests.
  *
  * See igt_subtest_with_dynamic_subsubtests_f() for documentation on
  * dynamic subsubtests.
  */
-#define igt_dynamic_subsubtest(name) for (; __igt_run_dynamic_subtest((name)) && \
-					  (sigsetjmp(igt_dynamic_subsubtest_jmpbuf, 1) == 0); \
+#define igt_dynamic(name) for (; __igt_run_dynamic_subtest((name)) && \
+					  (sigsetjmp(igt_dynamic_jmpbuf, 1) == 0); \
 				  igt_success())
-#define __igt_dynamic_subsubtest_f(tmp, format...) \
+#define __igt_dynamic_f(tmp, format...) \
 	for (char tmp [256]; \
 	     snprintf( tmp , sizeof( tmp ), \
 		      format), \
 	     __igt_run_dynamic_subtest( tmp ) && \
-	     (sigsetjmp(igt_dynamic_subsubtest_jmpbuf, 1) == 0); \
+	     (sigsetjmp(igt_dynamic_jmpbuf, 1) == 0); \
 	     igt_success())
 
 /**
- * igt_dynamic_subsubtest_f:
+ * igt_dynamic_f:
  * @...: format string and optional arguments
  *
  * This is a magic control flow block which denotes a dynamic
@@ -340,14 +340,14 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
  * variant accepts a printf format string, which is useful for
  * constructing combinatorial tests.
  *
  * See igt_subtest_with_dynamic_subsubtests_f() for documentation on
  * dynamic subsubtests.
  *
- * Like igt_dynamic_subsubtest(), but also accepts a printf format string
+ * Like igt_dynamic(), but also accepts a printf format string
  * instead of a static string.
  */
-#define igt_dynamic_subsubtest_f(f...) \
-	__igt_dynamic_subsubtest_f(igt_tokencat(__tmpchar, __LINE__), f)
+#define igt_dynamic_f(f...) \
+	__igt_dynamic_f(igt_tokencat(__tmpchar, __LINE__), f)
 
 const char *igt_subtest_name(void);
 bool igt_only_list_subtests(void);
@@ -238,13 +238,13 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
  * combinatorial tests.
  *
- * See igt_subtest_with_dynamic_subsubtests_f() for documentation.
+ * See igt_subtest_with_dynamic_f() for documentation.
  */
@@ -316,22 +316,22 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
  * constructing combinatorial tests.
  *
- * See igt_subtest_with_dynamic_subsubtests_f() for documentation on
+ * See igt_subtest_with_dynamic_f() for documentation on
  * dynamic subsubtests.
  */
@@ -340,14 +340,14 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
  * constructing combinatorial tests.
  *
- * See igt_subtest_with_dynamic_subsubtests_f() for documentation on
+ * See igt_subtest_with_dynamic_f() for documentation on
  * dynamic subsubtests.
  *
-- 
2.19.1

_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply related	[flat|nested] 7+ messages in thread

* Re: [igt-dev] [PATCH i-g-t 1/1] Rename dynamic subtest blocks
  2019-11-18 11:09 [igt-dev] [PATCH i-g-t 1/1] Rename dynamic subtest blocks Petri Latvala
@ 2019-11-18 11:16 ` Chris Wilson
  2019-11-18 11:50 ` Tvrtko Ursulin
                   ` (3 subsequent siblings)
  4 siblings, 0 replies; 7+ messages in thread
From: Chris Wilson @ 2019-11-18 11:16 UTC (permalink / raw)
  To: Petri Latvala, igt-dev; +Cc: Petri Latvala, Tvrtko Ursulin

Quoting Petri Latvala (2019-11-18 11:09:36)
> The final naming for the magic block identifiers is:
> 
> igt_subtest_with_dynamic("do-stuff-on-things") {
>     for_each_thing(x) {
>         igt_dynamic_f("%s", x->name) {
>             do_stuff(x);
>         }
>     }
> }
> 
> Signed-off-by: Petri Latvala <petri.latvala@intel.com>
> Cc: Chris Wilson <chris@chris-wilson.co.uk>
> Cc: Tvrtko Ursulin <tvrtko.ursulin@intel.com>
> Cc: Arkadiusz Hiler <arkadiusz.hiler@intel.com>
> Cc: Katarzyna Dec <katarzyna.dec@intel.com>

Worksforme,
Reviewed-by: Chris Wilson <chris@chris-wilson.co.uk>
-Chris
_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [igt-dev] [PATCH i-g-t 1/1] Rename dynamic subtest blocks
  2019-11-18 11:09 [igt-dev] [PATCH i-g-t 1/1] Rename dynamic subtest blocks Petri Latvala
  2019-11-18 11:16 ` Chris Wilson
@ 2019-11-18 11:50 ` Tvrtko Ursulin
  2019-11-18 12:40 ` [igt-dev] ✓ Fi.CI.BAT: success for series starting with [i-g-t,1/1] " Patchwork
                   ` (2 subsequent siblings)
  4 siblings, 0 replies; 7+ messages in thread
From: Tvrtko Ursulin @ 2019-11-18 11:50 UTC (permalink / raw)
  To: Petri Latvala, igt-dev; +Cc: Tvrtko Ursulin


On 18/11/2019 11:09, Petri Latvala wrote:
> The final naming for the magic block identifiers is:
> 
> igt_subtest_with_dynamic("do-stuff-on-things") {
>      for_each_thing(x) {
>          igt_dynamic_f("%s", x->name) {
> 	    do_stuff(x);
> 	}
>      }
> }
> 
> Signed-off-by: Petri Latvala <petri.latvala@intel.com>
> Cc: Chris Wilson <chris@chris-wilson.co.uk>
> Cc: Tvrtko Ursulin <tvrtko.ursulin@intel.com>
> Cc: Arkadiusz Hiler <arkadiusz.hiler@intel.com>
> Cc: Katarzyna Dec <katarzyna.dec@intel.com>

igt_dynamic sounds a bit generic but first come first served! :)

Acked-by: Tvrtko Ursulin <tvrtko.ursulin@intel.com>

Regards,

Tvrtko

> ---
> 
> NOTE!
> 
> The commit message is worded as being the final decision, but it's of
> course just a suggestion for the final naming and won't be used
> without acks, especially the people who have pointed out the awfulness
> of the naming. With luck I might have succeeded in CCing all of them
> and people otherwise involved in reviewing dynamic subtests.
> 
> These names meet the requirements laid out in words on the mailing
> list:
> 
> * makes it clear that the subtest that can have dynamic runtime parts
>    is a subtest more than an igt_subtest_group
> * don't completely destroy ickle's keyboard
> 
> 
> lib/igt_core.c                   |  4 +--
>   lib/igt_core.h                   | 46 ++++++++++++++++----------------
>   lib/tests/igt_describe.c         |  4 +--
>   lib/tests/igt_dynamic_subtests.c | 18 ++++++-------
>   4 files changed, 36 insertions(+), 36 deletions(-)
> 
> diff --git a/lib/igt_core.c b/lib/igt_core.c
> index a0c673d1..99aa0bee 100644
> --- a/lib/igt_core.c
> +++ b/lib/igt_core.c
> @@ -127,7 +127,7 @@
>    *
>    * - Code blocks with magic control flow are implemented with setjmp()
>    *   and longjmp(). This applies to #igt_fixture, #igt_subtest,
> - *   #igt_subtest_with_dynamic_subsubtests and #igt_dynamic_subsubtest
> + *   #igt_subtest_with_dynamic and #igt_dynamic
>    *   blocks and all the three variants to finish test: igt_success(),
>    *   igt_skip() and igt_fail(). Mostly this is of no concern, except
>    *   when such a control block changes stack variables defined in the
> @@ -1281,7 +1281,7 @@ static void exit_subtest(const char *result)
>   	const char *subtest_text = in_dynamic_subtest ? "Dynamic subtest" : "Subtest";
>   	const char **subtest_name = in_dynamic_subtest ? &in_dynamic_subtest : &in_subtest;
>   	struct timespec *thentime = in_dynamic_subtest ? &dynamic_subtest_time : &subtest_time;
> -	jmp_buf *jmptarget = in_dynamic_subtest ? &igt_dynamic_subsubtest_jmpbuf : &igt_subtest_jmpbuf;
> +	jmp_buf *jmptarget = in_dynamic_subtest ? &igt_dynamic_jmpbuf : &igt_subtest_jmpbuf;
>   
>   	igt_gettime(&now);
>   
> diff --git a/lib/igt_core.h b/lib/igt_core.h
> index 86bc1b41..c17a7ba8 100644
> --- a/lib/igt_core.h
> +++ b/lib/igt_core.h
> @@ -146,7 +146,7 @@ void __igt_fixture_end(void) __attribute__((noreturn));
>   
>   /* subtest infrastructure */
>   jmp_buf igt_subtest_jmpbuf;
> -jmp_buf igt_dynamic_subsubtest_jmpbuf;
> +jmp_buf igt_dynamic_jmpbuf;
>   typedef int (*igt_opt_handler_t)(int opt, int opt_index, void *data);
>   #define IGT_OPT_HANDLER_SUCCESS 0
>   #define IGT_OPT_HANDLER_ERROR -2
> @@ -230,7 +230,7 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
>   	__igt_subtest_f(igt_tokencat(__tmpchar, __LINE__), f)
>   
>   /**
> - * igt_subtest_with_dynamic_subsubtests:
> + * igt_subtest_with_dynamic:
>    * @name: name of the subtest
>    *
>    * This is a magic control flow block which denotes a subtest code
> @@ -238,13 +238,13 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
>    * printf format string, which is useful for constructing
>    * combinatorial tests.
>    *
> - * See igt_subtest_with_dynamic_subsubtests_f() for documentation.
> + * See igt_subtest_with_dynamic_f() for documentation.
>    */
> -#define igt_subtest_with_dynamic_subsubtests(name) for (; __igt_run_subtest((name), __FILE__, __LINE__) && \
> +#define igt_subtest_with_dynamic(name) for (; __igt_run_subtest((name), __FILE__, __LINE__) && \
>   							 __igt_enter_dynamic_container() && \
>   							 (sigsetjmp(igt_subtest_jmpbuf, 1) == 0); \
>   						 igt_success())
> -#define __igt_subtest_with_dynamic_subsubtests_f(tmp, format...) \
> +#define __igt_subtest_with_dynamic_f(tmp, format...) \
>   	for (char tmp [256]; \
>   	     snprintf( tmp , sizeof( tmp ), \
>   		      format), \
> @@ -254,7 +254,7 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
>   	     igt_success())
>   
>   /**
> - * igt_subtest_with_dynamic_subsubtests_f:
> + * igt_subtest_with_dynamic_f:
>    * @...: format string and optional arguments
>    *
>    * This is a magic control flow block which denotes a subtest code
> @@ -275,12 +275,12 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
>    * subsubtest for each pipe and performs the operation for that pipe
>    * in there.
>    *
> - * The result of a subtest igt_subtest_with_dynamic_subsubtests will be
> + * The result of a subtest igt_subtest_with_dynamic will be
>    * * SKIP, if no dynamic subsubtests are entered
>    * * PASS, if _all_ dynamic subsubtests PASS
>    * * FAIL, if _any_ dynamic subsubtests FAIL
>    *
> - * Within a igt_subtest_with_dynamic_subsubtests block, explicit
> + * Within a igt_subtest_with_dynamic block, explicit
>    * failure (e.g. igt_assert) is not allowed, only dynamic subsubtests
>    * themselves will produce test results. igt_skip()/igt_require() is
>    * allowed. Example:
> @@ -288,7 +288,7 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
>    * |[<!-- language="C" -->
>    * igt_main
>    * {
> - *     igt_subtest_with_dynamic_subsubtests("engine-tests") {
> + *     igt_subtest_with_dynamic("engine-tests") {
>    *               igt_require(is_awesome(fd)); // requires ok here
>    *
>    *               for_each_engine(fd, e) {
> @@ -300,14 +300,14 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
>    * }
>    * ]|
>    *
> - * Like igt_subtest_with_dynamic_subsubtests(), but also accepts a printf
> + * Like igt_subtest_with_dynamic(), but also accepts a printf
>    * format string instead of a static string.
>    */
> -#define igt_subtest_with_dynamic_subsubtests_f(f...) \
> -	__igt_subtest_with_dynamic_subsubtests_f(igt_tokencat(__tmpchar, __LINE__), f)
> +#define igt_subtest_with_dynamic_f(f...) \
> +	__igt_subtest_with_dynamic_f(igt_tokencat(__tmpchar, __LINE__), f)
>   
>   /**
> - * igt_dynamic_subsubtest:
> + * igt_dynamic:
>    * @name: name of the dynamic subtest
>    *
>    * This is a magic control flow block which denotes a dynamic
> @@ -316,22 +316,22 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
>    * variant accepts a printf format string, which is useful for
>    * constructing combinatorial tests.
>    *
> - * See igt_subtest_with_dynamic_subsubtests_f() for documentation on
> + * See igt_subtest_with_dynamic_f() for documentation on
>    * dynamic subsubtests.
>    */
> -#define igt_dynamic_subsubtest(name) for (; __igt_run_dynamic_subtest((name)) && \
> -					  (sigsetjmp(igt_dynamic_subsubtest_jmpbuf, 1) == 0); \
> +#define igt_dynamic(name) for (; __igt_run_dynamic_subtest((name)) && \
> +					  (sigsetjmp(igt_dynamic_jmpbuf, 1) == 0); \
>   				  igt_success())
> -#define __igt_dynamic_subsubtest_f(tmp, format...) \
> +#define __igt_dynamic_f(tmp, format...) \
>   	for (char tmp [256]; \
>   	     snprintf( tmp , sizeof( tmp ), \
>   		      format), \
>   	     __igt_run_dynamic_subtest( tmp ) && \
> -	     (sigsetjmp(igt_dynamic_subsubtest_jmpbuf, 1) == 0); \
> +	     (sigsetjmp(igt_dynamic_jmpbuf, 1) == 0); \
>   	     igt_success())
>   
>   /**
> - * igt_dynamic_subsubtest_f:
> + * igt_dynamic_f:
>    * @...: format string and optional arguments
>    *
>    * This is a magic control flow block which denotes a dynamic
> @@ -340,14 +340,14 @@ bool __igt_run_dynamic_subtest(const char *dynamic_subtest_name);
>    * variant accepts a printf format string, which is useful for
>    * constructing combinatorial tests.
>    *
> - * See igt_subtest_with_dynamic_subsubtests_f() for documentation on
> + * See igt_subtest_with_dynamic_f() for documentation on
>    * dynamic subsubtests.
>    *
> - * Like igt_dynamic_subsubtest(), but also accepts a printf format string
> + * Like igt_dynamic(), but also accepts a printf format string
>    * instead of a static string.
>    */
> -#define igt_dynamic_subsubtest_f(f...) \
> -	__igt_dynamic_subsubtest_f(igt_tokencat(__tmpchar, __LINE__), f)
> +#define igt_dynamic_f(f...) \
> +	__igt_dynamic_f(igt_tokencat(__tmpchar, __LINE__), f)
>   
>   const char *igt_subtest_name(void);
>   bool igt_only_list_subtests(void);
> diff --git a/lib/tests/igt_describe.c b/lib/tests/igt_describe.c
> index 7ea3b961..6f3a4319 100644
> --- a/lib/tests/igt_describe.c
> +++ b/lib/tests/igt_describe.c
> @@ -88,10 +88,10 @@ static void fake_main(int argc, char **argv) {
>   		;
>   
>   	igt_describe("Subtest with dynamic subsubtests");
> -	igt_subtest_with_dynamic_subsubtests("G") {
> +	igt_subtest_with_dynamic("G") {
>   		printf("should not be executed!\n");
>   		igt_describe("should assert on execution");
> -		igt_dynamic_subsubtest("should-not-list")
> +		igt_dynamic("should-not-list")
>   			printf("should not be executed!\n");
>   	}
>   
> diff --git a/lib/tests/igt_dynamic_subtests.c b/lib/tests/igt_dynamic_subtests.c
> index 82d80a77..606104c5 100644
> --- a/lib/tests/igt_dynamic_subtests.c
> +++ b/lib/tests/igt_dynamic_subtests.c
> @@ -56,7 +56,7 @@ static void dynamic_subtest_in_normal_subtest(void)
>   	igt_subtest_init(fake_argc, fake_argv);
>   
>   	igt_subtest("normal-subtest") {
> -		igt_dynamic_subsubtest("dynamic") {
> +		igt_dynamic("dynamic") {
>   			igt_info("Dynamic subtest in normal subtest\n");
>   		}
>   	}
> @@ -72,8 +72,8 @@ static void invalid_dynamic_subtest_name(void)
>   
>   	igt_subtest_init(fake_argc, fake_argv);
>   
> -	igt_subtest_with_dynamic_subsubtests("subtest") {
> -		igt_dynamic_subsubtest("# invalid name !") {
> +	igt_subtest_with_dynamic("subtest") {
> +		igt_dynamic("# invalid name !") {
>   			igt_info("Invalid dynamic subtest name test\n");
>   		}
>   	}
> @@ -89,7 +89,7 @@ static void dynamic_subtest_in_toplevel(void)
>   
>   	igt_subtest_init(fake_argc, fake_argv);
>   
> -	igt_dynamic_subsubtest("dynamic-subtest-in-toplevel") {
> +	igt_dynamic("dynamic-subtest-in-toplevel") {
>   		igt_info("Dynamic subtests need to be in a subtest\n");
>   	}
>   
> @@ -104,7 +104,7 @@ static void subtest_itself_failing(void)
>   
>   	igt_subtest_init(fake_argc, fake_argv);
>   
> -	igt_subtest_with_dynamic_subsubtests("subtest") {
> +	igt_subtest_with_dynamic("subtest") {
>   		igt_assert(false);
>   	}
>   
> @@ -119,7 +119,7 @@ static void subtest_itself_skipping(void)
>   
>   	igt_subtest_init(fake_argc, fake_argv);
>   
> -	igt_subtest_with_dynamic_subsubtests("subtest") {
> +	igt_subtest_with_dynamic("subtest") {
>   		igt_skip("Skipping\n");
>   	}
>   
> @@ -134,8 +134,8 @@ static void dynamic_subtest_failure_leads_to_fail(void)
>   
>   	igt_subtest_init(fake_argc, fake_argv);
>   
> -	igt_subtest_with_dynamic_subsubtests("subtest") {
> -		igt_dynamic_subsubtest("dynamic") {
> +	igt_subtest_with_dynamic("subtest") {
> +		igt_dynamic("dynamic") {
>   			igt_assert(false);
>   		}
>   	}
> @@ -151,7 +151,7 @@ static void no_dynamic_subtests_entered_leads_to_skip(void)
>   
>   	igt_subtest_init(fake_argc, fake_argv);
>   
> -	igt_subtest_with_dynamic_subsubtests("subtest") {
> +	igt_subtest_with_dynamic("subtest") {
>   	}
>   
>   	igt_exit();
> 
_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 7+ messages in thread

* [igt-dev] ✓ Fi.CI.BAT: success for series starting with [i-g-t,1/1] Rename dynamic subtest blocks
  2019-11-18 11:09 [igt-dev] [PATCH i-g-t 1/1] Rename dynamic subtest blocks Petri Latvala
  2019-11-18 11:16 ` Chris Wilson
  2019-11-18 11:50 ` Tvrtko Ursulin
@ 2019-11-18 12:40 ` Patchwork
  2019-11-18 13:02 ` [igt-dev] [PATCH i-g-t 1/1] " Arkadiusz Hiler
  2019-11-18 16:50 ` [igt-dev] ✓ Fi.CI.IGT: success for series starting with [i-g-t,1/1] " Patchwork
  4 siblings, 0 replies; 7+ messages in thread
From: Patchwork @ 2019-11-18 12:40 UTC (permalink / raw)
  To: Petri Latvala; +Cc: igt-dev

== Series Details ==

Series: series starting with [i-g-t,1/1] Rename dynamic subtest blocks
URL   : https://patchwork.freedesktop.org/series/69622/
State : success

== Summary ==

CI Bug Log - changes from CI_DRM_7361 -> IGTPW_3720
====================================================

Summary
-------

  **SUCCESS**

  No regressions found.

  External URL: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/index.html

Known issues
------------

  Here are the changes found in IGTPW_3720 that come from known issues:

### IGT changes ###

#### Issues hit ####

  * igt@gem_mmap@basic-small-bo:
    - fi-glk-dsi:         [PASS][1] -> [INCOMPLETE][2] ([fdo#103359] / [k.org#198133])
   [1]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/fi-glk-dsi/igt@gem_mmap@basic-small-bo.html
   [2]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/fi-glk-dsi/igt@gem_mmap@basic-small-bo.html

  * igt@i915_selftest@live_gem_contexts:
    - fi-bsw-n3050:       [PASS][3] -> [INCOMPLETE][4] ([fdo# 111542])
   [3]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/fi-bsw-n3050/igt@i915_selftest@live_gem_contexts.html
   [4]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/fi-bsw-n3050/igt@i915_selftest@live_gem_contexts.html

  * igt@i915_selftest@live_hangcheck:
    - fi-hsw-4770r:       [PASS][5] -> [DMESG-FAIL][6] ([fdo#111991])
   [5]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/fi-hsw-4770r/igt@i915_selftest@live_hangcheck.html
   [6]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/fi-hsw-4770r/igt@i915_selftest@live_hangcheck.html

  
#### Possible fixes ####

  * igt@gem_exec_create@basic:
    - {fi-tgl-u}:         [INCOMPLETE][7] ([fdo#111736]) -> [PASS][8]
   [7]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/fi-tgl-u/igt@gem_exec_create@basic.html
   [8]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/fi-tgl-u/igt@gem_exec_create@basic.html

  * igt@i915_selftest@live_blt:
    - fi-hsw-4770r:       [DMESG-FAIL][9] -> [PASS][10]
   [9]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/fi-hsw-4770r/igt@i915_selftest@live_blt.html
   [10]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/fi-hsw-4770r/igt@i915_selftest@live_blt.html
    - fi-hsw-peppy:       [DMESG-FAIL][11] ([fdo#112147]) -> [PASS][12]
   [11]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/fi-hsw-peppy/igt@i915_selftest@live_blt.html
   [12]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/fi-hsw-peppy/igt@i915_selftest@live_blt.html

  
#### Warnings ####

  * igt@kms_chamelium@hdmi-hpd-fast:
    - fi-kbl-7500u:       [FAIL][13] ([fdo#111045] / [fdo#111096]) -> [FAIL][14] ([fdo#111407])
   [13]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/fi-kbl-7500u/igt@kms_chamelium@hdmi-hpd-fast.html
   [14]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/fi-kbl-7500u/igt@kms_chamelium@hdmi-hpd-fast.html

  
  {name}: This element is suppressed. This means it is ignored when computing
          the status of the difference (SUCCESS, WARNING, or FAILURE).

  [fdo# 111542]: https://bugs.freedesktop.org/show_bug.cgi?id= 111542
  [fdo#103359]: https://bugs.freedesktop.org/show_bug.cgi?id=103359
  [fdo#109964]: https://bugs.freedesktop.org/show_bug.cgi?id=109964
  [fdo#111045]: https://bugs.freedesktop.org/show_bug.cgi?id=111045
  [fdo#111096]: https://bugs.freedesktop.org/show_bug.cgi?id=111096
  [fdo#111407]: https://bugs.freedesktop.org/show_bug.cgi?id=111407
  [fdo#111736]: https://bugs.freedesktop.org/show_bug.cgi?id=111736
  [fdo#111991]: https://bugs.freedesktop.org/show_bug.cgi?id=111991
  [fdo#112147]: https://bugs.freedesktop.org/show_bug.cgi?id=112147
  [fdo#112260]: https://bugs.freedesktop.org/show_bug.cgi?id=112260
  [fdo#112298]: https://bugs.freedesktop.org/show_bug.cgi?id=112298
  [k.org#198133]: https://bugzilla.kernel.org/show_bug.cgi?id=198133


Participating hosts (50 -> 45)
------------------------------

  Additional (1): fi-icl-y 
  Missing    (6): fi-hsw-4200u fi-byt-squawks fi-bsw-cyan fi-ctg-p8600 fi-byt-clapper fi-bdw-samus 


Build changes
-------------

  * CI: CI-20190529 -> None
  * IGT: IGT_5292 -> IGTPW_3720

  CI-20190529: 20190529
  CI_DRM_7361: 9dff9fddfefbd9c185b84b30e24a78687dce62c8 @ git://anongit.freedesktop.org/gfx-ci/linux
  IGTPW_3720: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/index.html
  IGT_5292: ea9cd47fdb72c16d5ec84c04a85122c451c30025 @ git://anongit.freedesktop.org/xorg/app/intel-gpu-tools

== Logs ==

For more details see: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/index.html
_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [igt-dev] [PATCH i-g-t 1/1] Rename dynamic subtest blocks
  2019-11-18 11:09 [igt-dev] [PATCH i-g-t 1/1] Rename dynamic subtest blocks Petri Latvala
                   ` (2 preceding siblings ...)
  2019-11-18 12:40 ` [igt-dev] ✓ Fi.CI.BAT: success for series starting with [i-g-t,1/1] " Patchwork
@ 2019-11-18 13:02 ` Arkadiusz Hiler
  2019-11-18 16:50 ` [igt-dev] ✓ Fi.CI.IGT: success for series starting with [i-g-t,1/1] " Patchwork
  4 siblings, 0 replies; 7+ messages in thread
From: Arkadiusz Hiler @ 2019-11-18 13:02 UTC (permalink / raw)
  To: Petri Latvala; +Cc: igt-dev, Tvrtko Ursulin

On Mon, Nov 18, 2019 at 01:09:36PM +0200, Petri Latvala wrote:
> The final naming for the magic block identifiers is:
> 
> igt_subtest_with_dynamic("do-stuff-on-things") {
>     for_each_thing(x) {
>         igt_dynamic_f("%s", x->name) {
> 	    do_stuff(x);
> 	}
>     }
> }
> 
> Signed-off-by: Petri Latvala <petri.latvala@intel.com>
> Cc: Chris Wilson <chris@chris-wilson.co.uk>
> Cc: Tvrtko Ursulin <tvrtko.ursulin@intel.com>
> Cc: Arkadiusz Hiler <arkadiusz.hiler@intel.com>
> Cc: Katarzyna Dec <katarzyna.dec@intel.com>

Acked-by: Arkadiusz Hiler <arkadiusz.hiler@intel.com>
_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 7+ messages in thread

* [igt-dev] ✓ Fi.CI.IGT: success for series starting with [i-g-t,1/1] Rename dynamic subtest blocks
  2019-11-18 11:09 [igt-dev] [PATCH i-g-t 1/1] Rename dynamic subtest blocks Petri Latvala
                   ` (3 preceding siblings ...)
  2019-11-18 13:02 ` [igt-dev] [PATCH i-g-t 1/1] " Arkadiusz Hiler
@ 2019-11-18 16:50 ` Patchwork
  2019-11-19 11:53   ` Petri Latvala
  4 siblings, 1 reply; 7+ messages in thread
From: Patchwork @ 2019-11-18 16:50 UTC (permalink / raw)
  To: Petri Latvala; +Cc: igt-dev

== Series Details ==

Series: series starting with [i-g-t,1/1] Rename dynamic subtest blocks
URL   : https://patchwork.freedesktop.org/series/69622/
State : success

== Summary ==

CI Bug Log - changes from CI_DRM_7361_full -> IGTPW_3720_full
====================================================

Summary
-------

  **SUCCESS**

  No regressions found.

  External URL: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/index.html

Known issues
------------

  Here are the changes found in IGTPW_3720_full that come from known issues:

### IGT changes ###

#### Issues hit ####

  * igt@gem_ctx_isolation@vcs0-s3:
    - shard-apl:          [PASS][1] -> [DMESG-WARN][2] ([fdo#108566])
   [1]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-apl4/igt@gem_ctx_isolation@vcs0-s3.html
   [2]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-apl4/igt@gem_ctx_isolation@vcs0-s3.html

  * igt@gem_eio@kms:
    - shard-kbl:          [PASS][3] -> [DMESG-WARN][4] ([fdo#105345])
   [3]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-kbl4/igt@gem_eio@kms.html
   [4]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-kbl2/igt@gem_eio@kms.html

  * igt@gem_exec_balancer@smoke:
    - shard-iclb:         [PASS][5] -> [SKIP][6] ([fdo#110854])
   [5]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb1/igt@gem_exec_balancer@smoke.html
   [6]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb7/igt@gem_exec_balancer@smoke.html

  * igt@gem_exec_reuse@baggage:
    - shard-iclb:         [PASS][7] -> [INCOMPLETE][8] ([fdo#107713] / [fdo#109100])
   [7]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb2/igt@gem_exec_reuse@baggage.html
   [8]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb7/igt@gem_exec_reuse@baggage.html

  * igt@gem_exec_schedule@deep-bsd:
    - shard-iclb:         [PASS][9] -> [SKIP][10] ([fdo#112146]) +2 similar issues
   [9]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb5/igt@gem_exec_schedule@deep-bsd.html
   [10]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb1/igt@gem_exec_schedule@deep-bsd.html

  * igt@gem_exec_schedule@preempt-queue-bsd1:
    - shard-iclb:         [PASS][11] -> [SKIP][12] ([fdo#109276]) +16 similar issues
   [11]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb2/igt@gem_exec_schedule@preempt-queue-bsd1.html
   [12]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb7/igt@gem_exec_schedule@preempt-queue-bsd1.html

  * igt@gem_exec_schedule@preempt-queue-contexts-chain-render:
    - shard-tglb:         [PASS][13] -> [INCOMPLETE][14] ([fdo#111677])
   [13]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-tglb2/igt@gem_exec_schedule@preempt-queue-contexts-chain-render.html
   [14]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-tglb6/igt@gem_exec_schedule@preempt-queue-contexts-chain-render.html

  * igt@gem_exec_suspend@basic-s3:
    - shard-tglb:         [PASS][15] -> [INCOMPLETE][16] ([fdo#111736] / [fdo#111850])
   [15]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-tglb2/igt@gem_exec_suspend@basic-s3.html
   [16]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-tglb1/igt@gem_exec_suspend@basic-s3.html

  * igt@gem_persistent_relocs@forked-faulting-reloc-thrash-inactive:
    - shard-apl:          [PASS][17] -> [TIMEOUT][18] ([fdo#112113]) +1 similar issue
   [17]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-apl7/igt@gem_persistent_relocs@forked-faulting-reloc-thrash-inactive.html
   [18]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-apl7/igt@gem_persistent_relocs@forked-faulting-reloc-thrash-inactive.html

  * igt@gem_softpin@noreloc-s3:
    - shard-glk:          [PASS][19] -> [INCOMPLETE][20] ([fdo#103359] / [k.org#198133])
   [19]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-glk7/igt@gem_softpin@noreloc-s3.html
   [20]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-glk4/igt@gem_softpin@noreloc-s3.html

  * igt@gem_userptr_blits@map-fixed-invalidate-overlap-busy:
    - shard-snb:          [PASS][21] -> [DMESG-WARN][22] ([fdo#111870]) +1 similar issue
   [21]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-snb2/igt@gem_userptr_blits@map-fixed-invalidate-overlap-busy.html
   [22]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-snb7/igt@gem_userptr_blits@map-fixed-invalidate-overlap-busy.html

  * igt@i915_pm_rpm@system-suspend-devices:
    - shard-tglb:         [PASS][23] -> [INCOMPLETE][24] ([fdo#111832] / [fdo#111850])
   [23]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-tglb8/igt@i915_pm_rpm@system-suspend-devices.html
   [24]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-tglb4/igt@i915_pm_rpm@system-suspend-devices.html

  * igt@i915_selftest@live_perf:
    - shard-hsw:          [PASS][25] -> [INCOMPLETE][26] ([fdo#103540])
   [25]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-hsw2/igt@i915_selftest@live_perf.html
   [26]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-hsw5/igt@i915_selftest@live_perf.html

  * igt@kms_color@pipe-a-gamma:
    - shard-tglb:         [PASS][27] -> [FAIL][28] ([fdo#104782])
   [27]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-tglb9/igt@kms_color@pipe-a-gamma.html
   [28]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-tglb5/igt@kms_color@pipe-a-gamma.html

  * igt@kms_flip@2x-flip-vs-expired-vblank:
    - shard-glk:          [PASS][29] -> [FAIL][30] ([fdo#105363])
   [29]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-glk5/igt@kms_flip@2x-flip-vs-expired-vblank.html
   [30]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-glk1/igt@kms_flip@2x-flip-vs-expired-vblank.html

  * igt@kms_frontbuffer_tracking@fbc-1p-primscrn-pri-indfb-draw-pwrite:
    - shard-iclb:         [PASS][31] -> [FAIL][32] ([fdo#103167]) +6 similar issues
   [31]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb5/igt@kms_frontbuffer_tracking@fbc-1p-primscrn-pri-indfb-draw-pwrite.html
   [32]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb8/igt@kms_frontbuffer_tracking@fbc-1p-primscrn-pri-indfb-draw-pwrite.html

  * igt@kms_frontbuffer_tracking@fbcpsr-1p-primscrn-indfb-plflip-blt:
    - shard-tglb:         [PASS][33] -> [FAIL][34] ([fdo#103167]) +3 similar issues
   [33]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-tglb9/igt@kms_frontbuffer_tracking@fbcpsr-1p-primscrn-indfb-plflip-blt.html
   [34]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-tglb8/igt@kms_frontbuffer_tracking@fbcpsr-1p-primscrn-indfb-plflip-blt.html

  * igt@kms_frontbuffer_tracking@fbcpsr-1p-rte:
    - shard-iclb:         [PASS][35] -> [FAIL][36] ([fdo#103167] / [fdo#110378])
   [35]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb1/igt@kms_frontbuffer_tracking@fbcpsr-1p-rte.html
   [36]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb6/igt@kms_frontbuffer_tracking@fbcpsr-1p-rte.html

  * igt@kms_pipe_crc_basic@suspend-read-crc-pipe-a:
    - shard-kbl:          [PASS][37] -> [DMESG-WARN][38] ([fdo#108566]) +3 similar issues
   [37]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-kbl3/igt@kms_pipe_crc_basic@suspend-read-crc-pipe-a.html
   [38]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-kbl2/igt@kms_pipe_crc_basic@suspend-read-crc-pipe-a.html

  * igt@kms_psr@psr2_no_drrs:
    - shard-iclb:         [PASS][39] -> [SKIP][40] ([fdo#109441]) +1 similar issue
   [39]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb2/igt@kms_psr@psr2_no_drrs.html
   [40]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb8/igt@kms_psr@psr2_no_drrs.html

  * igt@kms_setmode@basic:
    - shard-apl:          [PASS][41] -> [FAIL][42] ([fdo#99912])
   [41]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-apl1/igt@kms_setmode@basic.html
   [42]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-apl2/igt@kms_setmode@basic.html

  * igt@kms_vblank@pipe-c-ts-continuation-dpms-suspend:
    - shard-kbl:          [PASS][43] -> [INCOMPLETE][44] ([fdo#103665])
   [43]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-kbl2/igt@kms_vblank@pipe-c-ts-continuation-dpms-suspend.html
   [44]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-kbl6/igt@kms_vblank@pipe-c-ts-continuation-dpms-suspend.html

  * igt@perf_pmu@busy-no-semaphores-vcs1:
    - shard-iclb:         [PASS][45] -> [SKIP][46] ([fdo#112080]) +10 similar issues
   [45]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb1/igt@perf_pmu@busy-no-semaphores-vcs1.html
   [46]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb3/igt@perf_pmu@busy-no-semaphores-vcs1.html

  
#### Possible fixes ####

  * igt@gem_ctx_exec@basic-invalid-context-vcs1:
    - shard-iclb:         [SKIP][47] ([fdo#112080]) -> [PASS][48] +10 similar issues
   [47]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb8/igt@gem_ctx_exec@basic-invalid-context-vcs1.html
   [48]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb1/igt@gem_ctx_exec@basic-invalid-context-vcs1.html

  * igt@gem_ctx_isolation@rcs0-s3:
    - shard-kbl:          [DMESG-WARN][49] ([fdo#108566]) -> [PASS][50] +5 similar issues
   [49]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-kbl4/igt@gem_ctx_isolation@rcs0-s3.html
   [50]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-kbl4/igt@gem_ctx_isolation@rcs0-s3.html

  * igt@gem_ctx_persistence@vcs1-mixed-process:
    - shard-iclb:         [SKIP][51] ([fdo#109276] / [fdo#112080]) -> [PASS][52]
   [51]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb6/igt@gem_ctx_persistence@vcs1-mixed-process.html
   [52]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb2/igt@gem_ctx_persistence@vcs1-mixed-process.html

  * igt@gem_ctx_shared@exec-single-timeline-bsd:
    - shard-iclb:         [SKIP][53] ([fdo#110841]) -> [PASS][54]
   [53]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb4/igt@gem_ctx_shared@exec-single-timeline-bsd.html
   [54]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb5/igt@gem_ctx_shared@exec-single-timeline-bsd.html

  * igt@gem_ctx_shared@q-smoketest-all:
    - shard-tglb:         [INCOMPLETE][55] ([fdo#111735]) -> [PASS][56]
   [55]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-tglb6/igt@gem_ctx_shared@q-smoketest-all.html
   [56]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-tglb1/igt@gem_ctx_shared@q-smoketest-all.html

  * igt@gem_eio@kms:
    - shard-snb:          [INCOMPLETE][57] ([fdo#105411]) -> [PASS][58]
   [57]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-snb4/igt@gem_eio@kms.html
   [58]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-snb5/igt@gem_eio@kms.html

  * {igt@gem_exec_parse_blt@bb-start-far}:
    - shard-glk:          [TIMEOUT][59] -> [PASS][60]
   [59]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-glk3/igt@gem_exec_parse_blt@bb-start-far.html
   [60]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-glk7/igt@gem_exec_parse_blt@bb-start-far.html

  * igt@gem_exec_schedule@preempt-other-chain-bsd:
    - shard-iclb:         [SKIP][61] ([fdo#112146]) -> [PASS][62] +3 similar issues
   [61]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb4/igt@gem_exec_schedule@preempt-other-chain-bsd.html
   [62]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb8/igt@gem_exec_schedule@preempt-other-chain-bsd.html

  * igt@gem_exec_suspend@basic-s3:
    - shard-apl:          [DMESG-WARN][63] ([fdo#108566]) -> [PASS][64]
   [63]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-apl6/igt@gem_exec_suspend@basic-s3.html
   [64]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-apl3/igt@gem_exec_suspend@basic-s3.html

  * igt@gem_userptr_blits@map-fixed-invalidate-busy-gup:
    - shard-hsw:          [DMESG-WARN][65] ([fdo#111870]) -> [PASS][66] +4 similar issues
   [65]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-hsw8/igt@gem_userptr_blits@map-fixed-invalidate-busy-gup.html
   [66]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-hsw5/igt@gem_userptr_blits@map-fixed-invalidate-busy-gup.html

  * igt@gem_userptr_blits@sync-unmap-cycles:
    - shard-snb:          [DMESG-WARN][67] ([fdo#111870]) -> [PASS][68] +1 similar issue
   [67]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-snb1/igt@gem_userptr_blits@sync-unmap-cycles.html
   [68]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-snb1/igt@gem_userptr_blits@sync-unmap-cycles.html

  * igt@kms_cursor_crc@pipe-b-cursor-suspend:
    - shard-snb:          [DMESG-WARN][69] ([fdo#102365]) -> [PASS][70]
   [69]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-snb4/igt@kms_cursor_crc@pipe-b-cursor-suspend.html
   [70]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-snb5/igt@kms_cursor_crc@pipe-b-cursor-suspend.html

  * igt@kms_frontbuffer_tracking@fbc-1p-offscren-pri-indfb-draw-render:
    - shard-iclb:         [FAIL][71] ([fdo#103167]) -> [PASS][72] +2 similar issues
   [71]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb7/igt@kms_frontbuffer_tracking@fbc-1p-offscren-pri-indfb-draw-render.html
   [72]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb5/igt@kms_frontbuffer_tracking@fbc-1p-offscren-pri-indfb-draw-render.html

  * igt@kms_frontbuffer_tracking@fbcpsr-1p-primscrn-cur-indfb-move:
    - shard-tglb:         [FAIL][73] ([fdo#103167]) -> [PASS][74] +1 similar issue
   [73]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-tglb8/igt@kms_frontbuffer_tracking@fbcpsr-1p-primscrn-cur-indfb-move.html
   [74]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-tglb7/igt@kms_frontbuffer_tracking@fbcpsr-1p-primscrn-cur-indfb-move.html

  * igt@kms_pipe_crc_basic@suspend-read-crc-pipe-d:
    - shard-tglb:         [INCOMPLETE][75] ([fdo#111850]) -> [PASS][76]
   [75]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-tglb1/igt@kms_pipe_crc_basic@suspend-read-crc-pipe-d.html
   [76]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-tglb5/igt@kms_pipe_crc_basic@suspend-read-crc-pipe-d.html

  * igt@kms_psr@psr2_cursor_render:
    - shard-iclb:         [SKIP][77] ([fdo#109441]) -> [PASS][78] +3 similar issues
   [77]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb8/igt@kms_psr@psr2_cursor_render.html
   [78]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb2/igt@kms_psr@psr2_cursor_render.html

  * igt@kms_vblank@pipe-c-ts-continuation-suspend:
    - shard-tglb:         [INCOMPLETE][79] ([fdo#111832] / [fdo#111850]) -> [PASS][80] +1 similar issue
   [79]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-tglb8/igt@kms_vblank@pipe-c-ts-continuation-suspend.html
   [80]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-tglb6/igt@kms_vblank@pipe-c-ts-continuation-suspend.html

  * igt@prime_vgem@fence-wait-bsd2:
    - shard-iclb:         [SKIP][81] ([fdo#109276]) -> [PASS][82] +19 similar issues
   [81]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb8/igt@prime_vgem@fence-wait-bsd2.html
   [82]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb2/igt@prime_vgem@fence-wait-bsd2.html

  
#### Warnings ####

  * igt@gem_ctx_isolation@vcs1-nonpriv:
    - shard-iclb:         [SKIP][83] ([fdo#109276] / [fdo#112080]) -> [FAIL][84] ([fdo#111329]) +1 similar issue
   [83]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-iclb3/igt@gem_ctx_isolation@vcs1-nonpriv.html
   [84]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-iclb1/igt@gem_ctx_isolation@vcs1-nonpriv.html

  * igt@gem_ctx_isolation@vcs2-reset:
    - shard-tglb:         [SKIP][85] ([fdo#112080]) -> [SKIP][86] ([fdo#111912] / [fdo#112080])
   [85]: https://intel-gfx-ci.01.org/tree/drm-tip/CI_DRM_7361/shard-tglb9/igt@gem_ctx_isolation@vcs2-reset.html
   [86]: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/shard-tglb6/igt@gem_ctx_isolation@vcs2-reset.html

  
  {name}: This element is suppressed. This means it is ignored when computing
          the status of the difference (SUCCESS, WARNING, or FAILURE).

  [fdo#102365]: https://bugs.freedesktop.org/show_bug.cgi?id=102365
  [fdo#103167]: https://bugs.freedesktop.org/show_bug.cgi?id=103167
  [fdo#103359]: https://bugs.freedesktop.org/show_bug.cgi?id=103359
  [fdo#103540]: https://bugs.freedesktop.org/show_bug.cgi?id=103540
  [fdo#103665]: https://bugs.freedesktop.org/show_bug.cgi?id=103665
  [fdo#104782]: https://bugs.freedesktop.org/show_bug.cgi?id=104782
  [fdo#105345]: https://bugs.freedesktop.org/show_bug.cgi?id=105345
  [fdo#105363]: https://bugs.freedesktop.org/show_bug.cgi?id=105363
  [fdo#105411]: https://bugs.freedesktop.org/show_bug.cgi?id=105411
  [fdo#107713]: https://bugs.freedesktop.org/show_bug.cgi?id=107713
  [fdo#108566]: https://bugs.freedesktop.org/show_bug.cgi?id=108566
  [fdo#109100]: https://bugs.freedesktop.org/show_bug.cgi?id=109100
  [fdo#109276]: https://bugs.freedesktop.org/show_bug.cgi?id=109276
  [fdo#109441]: https://bugs.freedesktop.org/show_bug.cgi?id=109441
  [fdo#110378]: https://bugs.freedesktop.org/show_bug.cgi?id=110378
  [fdo#110841]: https://bugs.freedesktop.org/show_bug.cgi?id=110841
  [fdo#110854]: https://bugs.freedesktop.org/show_bug.cgi?id=110854
  [fdo#111329]: https://bugs.freedesktop.org/show_bug.cgi?id=111329
  [fdo#111677]: https://bugs.freedesktop.org/show_bug.cgi?id=111677
  [fdo#111735]: https://bugs.freedesktop.org/show_bug.cgi?id=111735
  [fdo#111736]: https://bugs.freedesktop.org/show_bug.cgi?id=111736
  [fdo#111832]: https://bugs.freedesktop.org/show_bug.cgi?id=111832
  [fdo#111850]: https://bugs.freedesktop.org/show_bug.cgi?id=111850
  [fdo#111870]: https://bugs.freedesktop.org/show_bug.cgi?id=111870
  [fdo#111912]: https://bugs.freedesktop.org/show_bug.cgi?id=111912
  [fdo#112080]: https://bugs.freedesktop.org/show_bug.cgi?id=112080
  [fdo#112113]: https://bugs.freedesktop.org/show_bug.cgi?id=112113
  [fdo#112146]: https://bugs.freedesktop.org/show_bug.cgi?id=112146
  [fdo#99912]: https://bugs.freedesktop.org/show_bug.cgi?id=99912
  [k.org#198133]: https://bugzilla.kernel.org/show_bug.cgi?id=198133


Participating hosts (11 -> 8)
------------------------------

  Missing    (3): pig-skl-6260u pig-glk-j5005 pig-hsw-4770r 


Build changes
-------------

  * CI: CI-20190529 -> None
  * IGT: IGT_5292 -> IGTPW_3720
  * Piglit: piglit_4509 -> None

  CI-20190529: 20190529
  CI_DRM_7361: 9dff9fddfefbd9c185b84b30e24a78687dce62c8 @ git://anongit.freedesktop.org/gfx-ci/linux
  IGTPW_3720: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/index.html
  IGT_5292: ea9cd47fdb72c16d5ec84c04a85122c451c30025 @ git://anongit.freedesktop.org/xorg/app/intel-gpu-tools
  piglit_4509: fdc5a4ca11124ab8413c7988896eec4c97336694 @ git://anongit.freedesktop.org/piglit

== Logs ==

For more details see: https://intel-gfx-ci.01.org/tree/drm-tip/IGTPW_3720/index.html
_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 7+ messages in thread

* Re: [igt-dev] ✓ Fi.CI.IGT: success for series starting with [i-g-t,1/1] Rename dynamic subtest blocks
  2019-11-18 16:50 ` [igt-dev] ✓ Fi.CI.IGT: success for series starting with [i-g-t,1/1] " Patchwork
@ 2019-11-19 11:53   ` Petri Latvala
  0 siblings, 0 replies; 7+ messages in thread
From: Petri Latvala @ 2019-11-19 11:53 UTC (permalink / raw)
  To: igt-dev

On Mon, Nov 18, 2019 at 04:50:26PM +0000, Patchwork wrote:
> == Series Details ==
> 
> Series: series starting with [i-g-t,1/1] Rename dynamic subtest blocks
> URL   : https://patchwork.freedesktop.org/series/69622/
> State : success


Thanks for the acks, this has now been merged.

The conversion to dynamic subtests for i915 engines is tracked in
https://gitlab.freedesktop.org/drm/igt-gpu-tools/issues/44 and will
happen one binary at a time, as there's going to be a lot of renaming,
to get cibuglog filters renamed in sync. And at least one part of
dynamic subtest framework needs changing before _that_ can begin, so
stay tuned.

After engines, kernel selftest launchers get their turn, and at some
point, KMS pipes.



-- 
Petri Latvala
_______________________________________________
igt-dev mailing list
igt-dev@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/igt-dev

^ permalink raw reply	[flat|nested] 7+ messages in thread

end of thread, other threads:[~2019-11-19 12:06 UTC | newest]

Thread overview: 7+ messages (download: mbox.gz / follow: Atom feed)
-- links below jump to the message on this page --
2019-11-18 11:09 [igt-dev] [PATCH i-g-t 1/1] Rename dynamic subtest blocks Petri Latvala
2019-11-18 11:16 ` Chris Wilson
2019-11-18 11:50 ` Tvrtko Ursulin
2019-11-18 12:40 ` [igt-dev] ✓ Fi.CI.BAT: success for series starting with [i-g-t,1/1] " Patchwork
2019-11-18 13:02 ` [igt-dev] [PATCH i-g-t 1/1] " Arkadiusz Hiler
2019-11-18 16:50 ` [igt-dev] ✓ Fi.CI.IGT: success for series starting with [i-g-t,1/1] " Patchwork
2019-11-19 11:53   ` Petri Latvala

This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.